import { select,
         json,
         scaleLinear,
         extent,
         min,
         max,
         axisLeft,
         axisBottom,
         format
       } from "d3"

const svg = select('svg');


const width = +svg.attr('width');
const height = +svg.attr("height");
const xLegend = 'Dénivelé'
const yLegend = 'Puissance (Watt)'
const title = 'MMP by Dénivelé'

const render = data => {
  //   	 d.vmax = +d.vmax;
  //     d.temps = +d.temps;
  //     d.vitesse = +d.vitesse;
  //     d.ascension = +d.ascension;
  //     d.mpg = +d.mpg;
  //     d.weight = +d.weight;
  //     d.year = +d.year;

  const xValue = d => d.ascension
  const yValue = d => d.wkg
  const minVitesse = min(data, d => d.vitesse)
  const maxVitesse = max(data, d => d.vitesse)
  const vitesseDiff = maxVitesse - minVitesse
  const minRadius = 2
  const maxRadius = 20
  const radiusDiff = maxRadius - minRadius
  const radius = d =>
  	(d.vitesse - minVitesse)/vitesseDiff*radiusDiff+minRadius
  
  const margin = { top:50,
                   right: 40,
                   bottom: 100,
                   left: 100
                 };
  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight,0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  yAxisG.select('.domain').remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.append('text')
  	.attr('class', 'xLegend')
    .text(xLegend)
  	.attr('fill', 'black')
  	.attr('x', `${innerWidth / 2}`)
  	.attr('y', `${50}`);
  
  yAxisG.append('text')
  	.attr('class', 'xLegend')
    .text(yLegend)
  	.attr('transform', 'rotate(-90)')
  	.attr('fill', 'black')
  	.attr('x', -innerHeight / 2)
  	.attr('text-anchor','middle')
  	.attr('y', -50);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', d => radius(d));
  
  // g.selectAll('div').data(data)
  // 	.enter().append('div')
  // 		.attr('class', 'entries')
  // 		.style("top", "2px")
  //     .style("left", "3px")
  // 		.style('width', '10px')
  // 		.style('height', '10px');
  
  xAxisG.append('text')
  	.attr('class', 'title')
  	.attr('y', -innerHeight - 5)
  	.attr('x', `${innerWidth / 2}`)
  	.text(title);
  
  // select('body').selectAll('div').data(data)
  // 	.enter().append('div')
  // 		.style("position", "absolute")
  //   	.style("visibility", "hidden")
  // 		.text('test')
  
  const tooltip = select('body').append('pre')
  	.attr('class', 'tooltip')
  	.style("position", "absolute")
    .style("visibility", "hidden")
  	.style('transform', 'translate(-50%, 0)');
  const getInfo = d => `P: ${d.wkg} D: ${d.ascension}\nAcc: ${d.vitesse}`
  g.selectAll('circle')
  	.on("mouseover", d => tooltip.style("visibility", "visible").text(getInfo(d)))
  	.on("mousemove", function(){tooltip.style('top', `${event.pageY-50}px`).style('left', `${event.pageX}px`)})
    .on("mouseout", function(){tooltip.style("visibility", "hidden").text('')})
};



json('https://api.velobook.net/api/profil/values/98/power/600')
  .then(data => {
    data.forEach(d => {
      d.vitesse = +d.vitesse;
      d.ascension = +d.ascension;
      d.wkg = +d.wkg;
     /* d.horsepower = +d.horsepower;
      d.mpg = +d.mpg;
      d.weight = +d.weight;
      d.year = +d.year;*/
    });
  console.log(data)
	render(data)